package de.intevation.mxd.reader;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.IMarkerSymbol;
import com.esri.arcgis.display.ArrowMarkerSymbol;
import com.esri.arcgis.display.IRgbColor;
import com.esri.arcgis.display.RgbColor;

import org.w3c.dom.Element;
import java.awt.Color;

import java.io.IOException;

/**
 * Reads arrow marker symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class ArrowMarkerSymbolReader
extends AbstractSymbolReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(ArrowMarkerSymbolReader.class);

    /**
     * Private member.
     */
    private ArrowMarkerSymbol symbol;

    public ArrowMarkerSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof ArrowMarkerSymbol) {
            this.symbol = (ArrowMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a ArrowMarkerSymbol!");
        }
    }

    public ArrowMarkerSymbolReader(IMarkerSymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof ArrowMarkerSymbol) {
            this.symbol = (ArrowMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a ArrowMarkerSymbol!");
        }
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read() {
        logger.debug("read()");
        Element symbolElement = util.addSymbol(parent);

        try{
            if(symbol.getColor() instanceof IRgbColor) {
                IRgbColor color = (IRgbColor)symbol.getColor();
                Color c = new Color (
                    color.getRed(),
                    color.getGreen(),
                    color.getBlue());
                symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
                symbolElement.setAttribute("transparency",
                    String.valueOf(color.getTransparency()));
            }
            else {
                RgbColor col = new RgbColor();
                col.setRGB(symbol.getColor().getRGB());
                Color c = new Color (
                    col.getRed(),
                    col.getGreen(),
                    col.getBlue());
                symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
                symbolElement.setAttribute("transparency",
                    String.valueOf(col.getTransparency()));
            }
        }
        catch(IOException ioe) {
            logger.warn("Could not read color.");
        }

        try {
            symbolElement.setAttribute(
                "angle",
                String.valueOf(symbol.getAngle()));
        }
        catch(IOException ioe) {
            logger.warn("Could not read angle.");
        }

        try {
            symbolElement.setAttribute(
                "size",
                String.valueOf(symbol.getSize()));
        }
        catch(IOException ioe) {
            logger.warn("Could not read size. Setting size to 1.");
            symbolElement.setAttribute("size", "1");
        }

        try {
            symbolElement.setAttribute(
                "x_offset",
                String.valueOf(symbol.getXOffset()));
        }
        catch(IOException ioe) {
            logger.warn("Could not read x-offset.");
        }

        try {
            symbolElement.setAttribute(
                "y_offset",
                String.valueOf(symbol.getYOffset()));
        }
        catch(IOException ioe) {
            logger.warn("Could not read y-offset.");
        }

        try {
            symbolElement.setAttribute(
                "name",
                symbol.getNameString());
        }
        catch(IOException ioe) {
            logger.warn("Could not read name. Setting name to \"default\"");
            symbolElement.setAttribute("name", "default");
        }

        try {
            symbolElement.setAttribute(
                "length",
                String.valueOf(symbol.getLength()));
        }
        catch(IOException ioe) {
            logger.warn("Could not read length.");
        }

        try {
            symbolElement.setAttribute(
                "width",
                String.valueOf(symbol.getWidth()));
        }
        catch(IOException ioe) {
            logger.warn("Could not read width.");
        }
        symbolElement.setAttribute("style", "arrow");
        symbolElement.setAttribute("type", "marker");
        return symbolElement;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
